import Toolbar from '@mui/material/Toolbar'
import IconButton from '@mui/material/IconButton'
import MenuIcon from '@mui/icons-material/Menu';
import SearchIcon from '@mui/icons-material/Search';
import InputBase from '@mui/material/InputBase';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import { styled, alpha } from '@mui/material/styles';
import { makeStyles } from '@material-ui/core'
import { useState, useRef, useEffect } from 'react';
import { createPortal } from 'react-dom';

import SearchBar from './SearchBar'
import ChatsList from './ChatsList'
import MenuBar from './MenuBar'



const Search = styled('div')(({ theme }:any) => ({
  position: 'relative',
  borderRadius: theme.shape.borderRadius,
  backgroundColor: alpha(theme.palette.common.white, 0.15),
  '&:hover': {
    backgroundColor: alpha(theme.palette.common.white, 0.25),
  },
  marginLeft: 0,
  width: '100%',
  [theme.breakpoints.up('sm')]: {
    marginLeft: theme.spacing(1),
    width: 'auto',
  },
}));

const SearchIconWrapper = styled('div')(({ theme }) => ({
  padding: theme.spacing(0, 2),
  height: '100%',
  position: 'absolute',
  pointerEvents: 'none',
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
}));

const StyledInputBase = styled(InputBase)(({ theme }) => ({
    color: 'inherit',
    '& .MuiInputBase-input': {
    background: '#f1f0f0',
    borderRadius: '20px',
    padding: theme.spacing(1, 1, 1, 0),
    paddingLeft: `calc(1em + ${theme.spacing(4)})`,
    transition: theme.transitions.create('width'),
    width: '100%',
    [theme.breakpoints.up('sm')]: {
      width: '35ch',
      '&:focus': {
          color: '#2184f7',
          outline: '2px solid  #2184f7',
          background: '#f5f5f5'
      },
    },
  },
}));

const useStyles = makeStyles({
    toolBar: {
        background: '#ffffff',
        color: 'rgba(0, 0, 0, 0.87)'
  },
  iconBtn: {
    '&:hover': {
      transform: 'rotate(180deg)',
      transition: 'all 250ms ease-out ',
    }
  },
  iconArrow: {
    '&:hover': {
      transform: 'rotate(360deg)',
      transition: 'all 250ms ease-out ',
    }
  },
})

const ContactsBar = () => {
    const classes = useStyles()
    const [isOpen, setIsOpen] = useState<boolean>(false)
    const [isMenu, setIsMenu] = useState<boolean>(false)
    const [value, setValue] = useState<string>('')
    const portalModal = useRef<HTMLDivElement|null>(null);
    const handleFocus = (): void => setIsOpen(true)
    const handleClick = (): void => {
       if(!isOpen) return setIsMenu(!isMenu)
       setIsOpen(false)
       }
  const handleSearch = (e: React.ChangeEvent<HTMLInputElement>) => setValue(e.target.value)
  useEffect(() => {
    const handleCloseModal = () => setIsMenu(false)
    const modal = document.getElementById('modal') as HTMLDivElement
    modal.addEventListener('click',handleCloseModal)
    portalModal.current = modal
    return () => {
      portalModal.current?.removeEventListener('click',handleCloseModal)
      portalModal.current = null
    }
  }, [])

    return (
    <>
        <Toolbar className={classes.toolBar}>
            <IconButton aria-label="" onClick={handleClick}>
                {isOpen ? <ArrowBackIcon className={classes.iconArrow} /> : <MenuIcon className={classes.iconBtn} />}
            </IconButton>
            <Search>
                <SearchIconWrapper>
                    <SearchIcon />
                </SearchIconWrapper>
                <StyledInputBase
                 onFocus={handleFocus}
                 onChange={handleSearch}
                 placeholder="Search"
                 inputProps={{ 'aria-label': 'search' }}
                />
            </Search>
        </Toolbar>
        {isOpen ? <SearchBar /> : <ChatsList />}
        {isMenu&&portalModal.current&&createPortal(<MenuBar/>,portalModal.current)}
    </>
    )
}

export default ContactsBar